@@ -30,11 +30,6 @@ from . mi_models import Endpoint
 
 from . mi_endpoints import mi_endpoint_get
 
-class ArgumentError(Exception):
-    '''Argument are not aligned with expectations'''
-
-
-
 
 class MiApi:
     def __init__(self, host: str, port: int, usr: str, pwd: str):
@@ -90,7 +85,7 @@ class MiApi:
             return None
 
 
-@lru_cache(10)
+@lru_cache(100)
 def mi_meta(endpoint: str, program: Optional[str] = None, transaction: Optional[str] = None) -> Union[MiPrograms, MiProgramMetadata, MiTransactionMetadata, MiError]:
     ''' Fetch metatdata from the API. Wrapper function for the following functions:
     - mi_meta_list
