@@ -14,7 +14,7 @@ from typing import Dict, List, Optional
 @dataclass
 class Base:
     def __iter__(self):
-        yield asdict(self).items()
+        return iter(asdict(self).items())
 
 
 @dataclass
