@@ -12,6 +12,7 @@ Email: kim.timothy.engh@epiroc.com
 Licence: GPLv3. See ../LICENCE '''
 
 from typing import Union
+from functools import cache
 from xml.etree import ElementTree
 
 from .mi_models import MiRecords
@@ -22,12 +23,13 @@ from .mi_models import MiFieldMetadata
 from .mi_models import MiError
 
 
+@cache
 def parse_xml(xml_str: Union[str, bytes]) -> ElementTree.ElementTree:
     ''' Parses a xml string and returns the element tree. '''
     xml_element_tree = ElementTree.ElementTree(ElementTree.fromstring(xml_str))
     return xml_element_tree
 
-
+@cache
 def xml_ns_tag(xml_str: Union[str, bytes]) -> str:
     ''' Returns the XML name space as a string'''
     xml_ns_tag = parse_xml(xml_str).getroot().tag.split('}')[0] + '}'
